@@ -15,7 +15,7 @@ from constants import (BREADTH_FIRST, DEPTH_FIRST,
                        NODE_GLOBAL, NODE_PATH, NODE_RECENT,
                        RELATIONSHIP_GLOBAL, RELATIONSHIP_PATH,
                        RELATIONSHIP_RECENT, NONE,
-                       NODE, RELATIONSHIP, PATH, POSITION,
+                       NODE, RELATIONSHIP, PATH, POSITION, FULLPATH,
                        INDEX_FULLTEXT, TX_GET, TX_PUT, TX_POST, TX_DELETE,
                        RELATIONSHIPS_ALL, RELATIONSHIPS_IN, RELATIONSHIPS_OUT,
                        RETURN_ALL_NODES, RETURN_ALL_BUT_START_NODE)
@@ -1010,13 +1010,15 @@ class Index(object):
                 raise TypeError("%s is a %s and the index is for %ss"
                                 % (item, self._index_for.capitalize(),
                                    self._index_for))
-            value = smart_quote(value)
             if isinstance(item, Base):
                 url_ref = item.url
             else:
                 url_ref = item
-            request_url = "%s/%s" % (self.url, value)
-            response, content = Request().post(request_url, data=url_ref)
+            request_url_and_key = self.url.rsplit('/', 1)  # assumes the key
+            data = {"key": request_url_and_key[1],
+                    "value": value,  # smart_quote is not needed anymore here
+                    "uri": url_ref}
+            response, content = Request().post(request_url_and_key[0], data=data)
             if response.status == 201:
                 # Returns object that was indexed
                 entity = json.loads(content)
@@ -1027,7 +1029,8 @@ class Index(object):
             else:
                 raise StatusException(response.status,
                                       "Error requesting index with POST %s " \
-                                      ", data %s" % (request_url, url_ref))
+                                      ", data %s" % (request_url_and_key[0],
+                                                     url_ref))
 
         def query(self, value):
             url = "%s?query=%s" % (self.url, smart_quote(value))
@@ -1364,7 +1367,6 @@ class BaseInAndOut(object):
 
     def __init__(self, direction):
         self.direction = direction
-       
 
     def get(self, attr):
         return self.__getattr__(attr)
